@@ -1,5 +1,5 @@
-#  tests for lightgbm-3.2.1-py38h885f38d_0 (this is a generated file);
-print('===== testing package: lightgbm-3.2.1-py38h885f38d_0 =====');
+#  tests for lightgbm-3.3.1-py38h885f38d_0 (this is a generated file);
+print('===== testing package: lightgbm-3.3.1-py38h885f38d_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 """
@@ -12,6 +12,7 @@ functional test here that is adapted from:
 
 """
 
+import platform
 import unittest
 
 import lightgbm as lgb
@@ -23,7 +24,7 @@ from sklearn.model_selection import train_test_split
 
 class TestSklearn(unittest.TestCase):
     def test_binary(self):
-        X, y = load_breast_cancer(True)
+        X, y = load_breast_cancer(return_X_y=True)
         X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.1, random_state=42)
         gbm = lgb.LGBMClassifier(n_estimators=50, silent=True)
         gbm.fit(X_train, y_train, eval_set=[(X_test, y_test)], early_stopping_rounds=5, verbose=False)
@@ -32,7 +33,7 @@ class TestSklearn(unittest.TestCase):
         self.assertAlmostEqual(ret, gbm.evals_result_['valid_0']['binary_logloss'][gbm.best_iteration_ - 1], places=5)
 
     def test_regression(self):
-        X, y = load_boston(True)
+        X, y = load_boston(return_X_y=True)
         X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.1, random_state=42)
         gbm = lgb.LGBMRegressor(n_estimators=50, silent=True)
         gbm.fit(X_train, y_train, eval_set=[(X_test, y_test)], early_stopping_rounds=5, verbose=False)
@@ -42,10 +43,11 @@ class TestSklearn(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    unittest.main()
+    if platform.machine() != "ppc64le":
+        unittest.main()
 #  --- run_test.py (end) ---
 
-print('===== lightgbm-3.2.1-py38h885f38d_0 OK =====');
+print('===== lightgbm-3.3.1-py38h885f38d_0 OK =====');
 print("import: 'lightgbm'")
 import lightgbm
 
